/*
 * Copyright (c) 2007 - 2011 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.sys.funclib.kbgen.ProxySetDescription
 *
 * de.bsvrz.sys.funclib.kbgen.ProxySetDescription is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxySetDescription is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.sys.funclib.kbgen.ProxySetDescription; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * Koelner Strasse 30
 * D-50859 Kln
 * +49 (0)2234 4301 800
 * info@invat.de
 * www.inovat.de
 */

package de.bsvrz.sys.funclib.kbgen;

import java.util.List;

/**
 * Objekt, ber den die (konfigurierenden) Mengen einer Attributgruppe fr ein Objekt mit den Objektreferenzen innerhalb
 * der Attributgruppe verknpft werden.<p> Erluterung: Die Klasse {@link ConfigAreaCreator} erzeugt aus den ihr
 * bergebenen Objekten vom Typ {@link ProxyConfigurationObject} die Objektdefinitionen fr einen Konfigurationsbereich
 * im Datenkatalog. Dazu enthlt ein {@link ProxyConfigurationObject} alle Informationen zu dem zu erzeugenden
 * Konfigurationsobjekt. Dies sind neben Typ, Name und Pid insbesondere die Informationen zu den konfigurierenden
 * Attributgruppen und den Mengen. Damit die Klasse {@link ConfigAreaCreator} die Informationen zu den konfigurierenden
 * Attributgruppen genenerisch ermitteln kann, halt ein {@link ProxyConfigurationObject} zu jeder konfigurierenden
 * Attributgruppe die Daten in Form einer {@link de.bsvrz.dav.daf.main.Data} Struktur, ber die generisch iteriert
 * werden kann. Das Problem besteht nun darin, dass Objektreferenzen in einer solchen {@link de.bsvrz.dav.daf.main.Data}
 * Struktur bei der Erstellung des {@link ProxyConfigurationObject} nicht eingetragen werden knnen, da dass
 * referenzierte Objekt i. d. R. noch gar nicht in der Konfiguration verfgbar ist. Der Versuch eine solche Referenz
 * anzulegen fhrt deshalb zu einem Fehler. Aus diesem Grund wird zu einem {@link de.bsvrz.dav.daf.main.Data} Objekt
 * zustzlich eine Liste mit den Pid der zu referenzierenden Objekte mitgefhrt, wobei die Reihenfolge der Eintrge in
 * der Liste der Reihenfolge der Objektreferenzen im {@link de.bsvrz.dav.daf.main.Data} Objekt entspricht. Bei der
 * Auswertung der Informationen durch die Klasse {@link ConfigAreaCreator} ermittelt diese dann den Wert einer Referenz
 * nicht aus dem {@link de.bsvrz.dav.daf.main.Data} Objekt, sondern aus dem entsprechenden Eintrag der Liste.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kni (HCK)
 * @version $Revision: 513 $ / $Date: 2011-04-13 14:23:45 +0200 (Mi, 13 Apr 2011) $ / ($Author: HCK $)
 */

public class ProxySetDescription {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

	List<String> _elements;
	String _name;

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt eine Beschreibung der Menge an einem ProxyKonfigurationsobjekt.
	 *
	 * @param name     Konfigurierende Daten.
	 * @param elements Liste der Pids mit Elementen der Menge.
	 */
	public ProxySetDescription(String name, List<String> elements) {
		_name = name;
		_elements = elements;
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	/**
	 * Liefert die Liste der Pids mit den Objektreferenzen.
	 *
	 * @return Liste der Pids mit den im {@link de.bsvrz.dav.daf.main.Data} Objekt fehlenden Objektreferenzen.
	 */
	public List<String> getElements() {
		return _elements;
	}

	/**
	 * Liefert das {@link de.bsvrz.dav.daf.main.Data} Objekt.
	 *
	 * @return {@link de.bsvrz.dav.daf.main.Data} Objekt mit nicht gesetzten Objektreferenzen.
	 */
	public String getName() {
		return _name;
	}

// ------------------------------------------------------------------------
// KANONISCHE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Gibt die String-Reprsentation dieses Objekts aus.
	 * <p/>
	 * Die Formatierung der Ausgabe kann sich ndern und wird nicht garantiert.
	 *
	 * @return Aktueller Zustand der Klassenvariablen dieses Objekts.
	 */
	public String toString() {
		return "ProxySetDescription{" +
		       "_elements=" + _elements +
		       ", _name='" + _name + '\'' +
		       '}';
	}
}


